---
hide:
  - navigation
  - toc
---
# 

<div
  style="
    text-align: center;
    width: 50%;
    margin: auto;
    font-size: 2em;
    font-weight: bold;
    margin-top: -5%;
  "
>
  Welcome to unitorch
</div>

<div style="text-align: center; width: 70%; margin: auto; margin-top: 5%">
  🔥 <b>unitorch</b> is a library that simplifies and accelerates the
  development of unified models for <b>NLP</b>, <b>NLG</b>, <b>CV</b>,
  <b>CTR</b>, <b>MM</b> and <b>RL</b>. It is built on top of PyTorch and
  integrates seamlessly with popular frameworks such as transformers, peft,
  diffusers and fastseq.
</div>

<div style="text-align: center; width: 60%; margin: auto; margin-top: 5%">
  <a
    href="overview/"
    title="Get Started"
    class="md-button md-button--primary"
    style="background-color: black; border: 0px"
  >
    Get started
    <svg
      width="11"
      height="10"
      viewBox="0 0 11 10"
      fill="none"
      style="margin-left: 2px"
    >
      <path
        d="M1 5.16772H9.5M9.5 5.16772L6.5 1.66772M9.5 5.16772L6.5 8.66772"
        stroke="currentColor"
        stroke-width="2"
        stroke-linecap="round"
        stroke-linejoin="round"
      ></path>
    </svg>
  </a>
</div>

<div style="text-align: center; width: 80%; margin: auto; margin-top: 5%; margin-bottom: 5%">
<img src="overview.png"/>
</div>